#!/bin/bash
# SmedgeMaster daemon control script
#
# Smedge
# Copyright (c) 2004 - 2012 Uberware. All rights reserved
#
# chkconfig:   2345 98 2
# description: Control the Smedge 3 SmedgeMaster process as a daemon.


# find the actual excutable
	
if [ ! "$SMEDGE_BIN" ]; then

	#   This process will create a file in the current folder
	#   called _smedge3_startup.log. Use this file if there is
	#   any problem with the startup path detection system.
	#   Successful startup will delete this file before starting
	#   the detected binary executable.

	echo Checking startup folder from: $0 > ./_smedge3_startup.log

	# convert to absolute path
	case $0 in
		/*) exe=$0 ;;
		*) exe=`pwd`/$0 ;;
	esac

	echo Absolute folder: $exe >> ./_smedge3_startup.log

	# follow symlinks
	while [ -h $exe ]; do
		echo Symlink: $exe >> ./_smedge3_startup.log

		tgt=`ls -l $exe | tr ' ' '\012' | tail -1`
		echo ... Target: $tgt >> ./_smedge3_startup.log

		# check if the symlink is relative
		case $tgt in
		/*)	echo ... not detected as relative >> ./_smedge3_startup.log 
			exe=$tgt
			;;
		*)	echo ... detected as relative symlink >> ./_smedge3_startup.log
			dir=`dirname $exe`
			echo ... Got parent dir $dir from $exe >> ./_smedge3_startup.log
			exe=$dir/$tgt
			;;
		esac
	done

	echo The final startup folder is: >> ./_smedge3_startup.log
	echo $exe >> ./_smedge3_startup.log

	# check for a required library file
	check_dir=`dirname $exe`
	check_fil=libR.so
	if [ -e $check_dir/$check_fil ]; then
		SMEDGE_BIN=$check_dir
	else
		echo Smedge is not installed correctly on this machine
		echo Missing $check_dir/$check_fil
		echo Missing $check_dir/$check_fil >> ./_smedge3_startup.log
		if [ $1 = "stop" ]; then
			exit 0;
		else
			exit 1;
		fi
	fi
	export SMEDGE_BIN

	rm -f ./_smedge3_startup.log
fi

# add the Smedge folder to the LD_LIBRARY_PATH
if [ "$LD_LIBRARY_PATH" ]; then
	LD_LIBRARY_PATH="$SMEDGE_BIN:$LD_LIBRARY_PATH"
else
	LD_LIBRARY_PATH=$SMEDGE_BIN
fi
export LD_LIBRARY_PATH

# ensure there is a SMEDGE_MODULES
if [ "$SMEDGE_MODULES" ]; then
	SMEDGE_MODULES="$SMEDGE_MODULES;$SMEDGE_BIN/Modules"
else
	SMEDGE_MODULES="$SMEDGE_BIN/Modules"
fi
export SMEDGE_MODULES

# ensure that there is a SMEDGE_UMASK
if [ ! "$SMEDGE_UMASK" ]; then
	export SMEDGE_UMASK=022
fi

# find the correct /var/lock location
if [ -e "/var/lock/subsys" ]; then
	var_lock=/var/lock/subsys
else
	var_lock=/var/lock
fi

# define the daemon name and executable
NAME=SmedgeMaster
PROGRAM=$SMEDGE_BIN/SmedgeMaster.bin

# source the init function ibrary
. /lib/lsb/init-functions

# start and stop are implemented as functions
start() {
	echo -n "Starting $NAME: "

	# Try to start the daemon. To start as a different user you can
	# either export the SMEDGE_USER variable, or you can add the the
	# user name after the -daemon flag like this:
	#
	#   start_daemon $PROGRAM -daemon <user>
	#
	# To start as a different group, you must export the SMEDGE_GROUP
	# environment variable.
	#
	# You can also add any desired extra Smedge command line parameters
	# to the end of the daemon command line, like this:
	#
	#   daemon $PROGRAM -daemon -LogFileLevel 6 <etc...>

	start_daemon $PROGRAM -daemon
	
	# report result and set the lock
	RESULT=$?
	touch $var_lock/$NAME
	echo `pidof $PROGRAM` > /var/run/$NAME.pid
	echo
	return $RESULT
}	

stop() {
	echo -n "Shutting down $NAME: "
	
	# terminate the daemon
	killproc $PROGRAM
	
	# report result and unset the lock
	RESULT=$?
	rm -f $var_lock/$NAME
	rm -f /var/run/$NAME.pid
	echo
	return $RESULT
}

# perform the requested operation
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    status)
        status $NAME
        ;;
    restart)
        stop
        start
        ;;
    *)
        echo "Usage:  {start|stop|status|restart}"
        exit 1
        ;;
esac
exit $?
