#!/bin/sh -f
# Smedge daemon installer script
#
# Smedge 3
# Copyright (c) 2004 - 2011 Uberware. All rights reserved.



# Check for help request
case $1 in
	-h|--help)
		echo "`basename $0` [engine|master|control]"
		echo
		echo "Will attempt to install and start the requested daemon"
		echo "If no value is supplied, engine will be installed"
		echo "If invalid value is supplied, no changes will be made"
		echo
		exit 2
		;;
esac


# Configuration:

# default root uid is 0
ROOT_UID=0

# default init.d path is /etc/init.d
INIT_PATH=/etc/init.d


# Find Smedge

# convert to absolute path

case $0 in
	/*) exe=$0 ;;
	*)  exe=`pwd`/$0 ;;
esac


# follow symlinks

while [ -h $exe ]; do
  tgt=`ls -l $exe | tr ' ' '\012' | tail -1`
  case $tgt in
  /*) exe=$tgt;;
  *)  _d_=`dirname $exe`
      exe=$_d_/$tgt;;
  esac
done


# this script should be in the <Smedge>/Utilities folder

SMEDGE_PATH=`dirname $exe`/..


# make sure we have root access

user_id=`id -u`
if [ $user_id -ne "$ROOT_UID" ]; then
  echo "You must be a priveliged user to install Smedge daemons"
  exit 1
fi



# install!

echo "Initializing Smedge daemon installation..."
echo "    Program Folder: $SMEDGE_PATH"
echo "    Daemon Folder:  $INIT_PATH"
echo


# get the daemon to install

if [ -z $1 ]; then
	# default is to install the Engine daemon
	command='engine'
else
	# correct the request if needed
	case $1 in
	
		# Install the Engine
		1*) 
			command='engine' ;;
		engine*)
			command='engine' ;;
		Engine*)
			command='engine' ;;
			
		# Install the Master
		2*)
			command='master' ;;
		master*)
			command='master' ;;
		Master*)
			command='master' ;;
				
		# Install the Engine Control
		3*)
			command='control' ;;
		control*)
			command='control' ;;
		Control*)
			command='control' ;;

	esac
fi


# use a common function to actually do the installation steps

install_daemon()
{
	echo "Installing $1 daemon..."
	
	# add to the init.d folder
	echo "    ln -sf $SMEDGE_PATH/$2.d $INIT_PATH/"
	ln -sf $SMEDGE_PATH/$2.d $INIT_PATH/
	
	# add to the rc?.d folder tree
	if [ -e /sbin/chkconfig ]; then
		echo "    /sbin/chkconfig --add $2.d"
		/sbin/chkconfig --add $2.d
	fi

	# start the daemon
	echo "    $INIT_PATH/$2.d start"
	$INIT_PATH/$2.d start
}


# perform the action to install the requested daemon

case $command in
	engine)
		install_daemon 'Engine' 'SmedgeEngine' ;;
	master)
		install_daemon 'Master' 'SmedgeMaster' ;;
	control)
		install_daemon 'Engine Control' 'Engine' ;;
	*)
		echo unknown daemon to install: $command ;;
esac
