#!/bin/sh -f
# Smedge daemon removal script
#
# Smedge 3
# Copyright (c) 2004 - 2010 Uberware. All rights reserved.



# Configuration:

# default root uid is 0
ROOT_UID=0

# default init.d path is /etc/init.d
INIT_PATH=/etc/init.d


# make sure we have root access

user_id=`id -u`
if [ $user_id -ne "$ROOT_UID" ]; then
  echo "You must be a priveliged user to remove Smedge daemons"
  exit 1
fi


# remove!

echo "Initializing Smedge daemon removal..."
echo "    Daemon Folder:  $INIT_PATH"
echo


# get the daemon to remove

if [ -z $1 ]; then
	# default is to remove the Engine daemon
	command='engine'
else
	# correct the request if needed
	case $1 in
	
		# Remove the Engine
		1*) 
			command='engine' ;;
		engine*)
			command='engine' ;;
		Engine*)
			command='engine' ;;
			
		# Remove the Master
		2*)
			command='master' ;;
		master*)
			command='master' ;;
		Master*)
			command='master' ;;
	
		# Remove the Engine Control
		3*)
			command='control' ;;
		control*)
			command='control' ;;
		Control*)
			command='control' ;;

	esac
fi


# use a common function to actually do the removal steps

remove_daemon()
{
	echo "Remove $1 daemon..."
	
	# stop the daemon
	if [ -e $INIT_PATH/$2.d ]; then
		echo "    $INIT_PATH/$2.d stop || :"
		$INIT_PATH/$2.d stop || :
	fi
	
	# remove from the rc?.d tree
	if [ -e /sbin/chkconfig ]; then
		echo "    /sbin/chkconfig --del $2.d"
		/sbin/chkconfig --del $2.d
	fi
	
	# remove from the init.d folder
	echo "    rm -f $INIT_PATH/$2.d"
	rm -f $INIT_PATH/$2.d
}


# perform the action to install the requested daemon

case $command in
	engine)
		remove_daemon 'Engine' 'SmedgeEngine' ;;
	master)
		remove_daemon 'Master' 'SmedgeMaster' ;;
	control)
		remove_daemon 'Engine Control' 'Engine' ;;
	*)
		echo unknown daemon to install: $command ;;
esac
